%       Please cite the following references:
%
%       [1] W. Liao, J. Chanussot, M. Dalla Mura, X. Huang, R. Bellens,
%           S. Gautama, W, Philips, "Taking Optimal Advantage of Fine Spatial 
%           Resolution: Promoting partial image reconstruction for the 
%           morphological analysis of very-high-resolution images",  IEEE 
%           Geoscience and Remote Sensing Magazine, vol. 5, no. 2, pp. 8-28, 2017.
%
%       [2] W. Liao, M. Dalla Mura, J. Chanussot, R. Bellens, W. Philips, 
%           "Morphological Attribute Profiles With Partial Reconstruction", 
%           IEEE Transactions on Geoscience and Remote Sensing, vol. 54, 
%           no. 3, pp. 1738-1756, 2016.
%
%       [3] R. Bellens, J. Chan, L. Martinez-Fonte, S. Gautama, F. Canters, 
%           W. Philips, "Improved classification of VHR images of urban areas 
%           using directional morphological profiles", IEEE Transactions on
%           Geoscience and Remote Sensing, vol. 46, no. 10, pp. 2803-2813, 2008.
%
%
%
%       Copyright notes
%       Author: Rik Bellens and Wenzhi Liao, IPI, Telin, Ghent University, Belgium
%       Date: 19/07/2016
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

classdef sequencestrel < basestrel
    
    properties (Access = protected)
        strels;
    end
    
    methods(Access = public)
        
        function obj = sequencestrel(strels)
            obj@basestrel([strels.matlabse]);
            obj.strels = strels;
        end
        
       
        function se = GetReflection(se)
            for i=1:length(se.strels)
                se.strels(i) = GetReflection(se.strels(i));
            end
        end
    end
    
    methods (Access = protected)
        
        function out = morphop(op,im,se,shape)
            out = im;
            for i=1:length(se.strels)
                out = feval(op,out,se.strels(i),'full');
            end
            [h,w] = size(im);
            [fullh,fullw] = size(out);
            if nargin<4||strcmp(shape,'same')
                out = out( (fullh-h)/2 + (1:h), (fullw-w)/2 + (1:w) );
            end
        end            
        
    end

end
